==> generator-ibm-java-spring-1.0.4.tgz: package/README.md <==
# Yeoman generator for Spring code

[![IBM Cloud powered][img-bluemix-powered]][url-bluemix]
[![Travis][img-travis]][url-travis]
[![Coveralls][img-coveralls-master]][url-coveralls-master]
[![Codacy][img-codacy]][url-codacy]
[![Version][img-version]][url-npm]
[![DownloadsMonthly][img-npm-downloads-monthly]][url-npm]
[![DownloadsTotal][img-npm-downloads-total]][url-npm]
[![License][img-license]][url-npm]
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)

[img-bluemix-powered]: https://img.shields.io/badge/bluemix-powered-blue.svg
[url-bluemix]: http://bluemix.net

[img-travis]: https://travis-ci.org/ibm-developer/generator-ibm-java-spring.svg?branch=master
[url-travis]: https://travis-ci.org/ibm-developer/generator-ibm-java-spring

[img-coveralls-master]: https://coveralls.io/repos/github/ibm-developer/generator-ibm-java-spring/badge.svg
[url-coveralls-master]: https://coveralls.io/github/ibm-developer/generator-ibm-java-spring

[img-codacy]: https://api.codacy.com/project/badge/Grade/a5893a4622094dc8920c8a372a8d3588?branch=development
[url-codacy]: https://www.codacy.com/app/ibm-developer/generator-ibm-java-spring

[img-version]: https://img.shields.io/npm/v/generator-ibm-java-spring.svg
[url-npm]: https://www.npmjs.com/package/generator-ibm-java-spring

[img-npm-downloads-monthly]: https://img.shields.io/npm/dm/generator-ibm-java-spring.svg

[img-npm-downloads-total]: https://img.shields.io/npm/dt/generator-ibm-java-spring.svg

[img-license]: https://img.shields.io/npm/l/generator-ibm-java-spring.svg

This is a [yeoman generator](http://yeoman.io/) that will create Java code for you.

## Getting started:

To run the Yeoman generator simply type the following:

```bash
yo @arf/java (this generator is actually a sub-generator that the main java generator will compose with)
```

The generator provides the ability to generate Spring Java applications.

[Bluemix](https://console.ng.bluemix.net/) starters provide infrastructure files for building locally with Maven or Gradle and deploying to IBM Bluemix using containers. They also include code snippets to connect to any Bluemix services that are selected as part of the generation.

## Contribution

In order to publish changes, you will need to fork the repository or ask to join the `ibm-developer` org and branch off the `master` branch.

Make sure to follow the [conventional commit specification](https://conventionalcommits.org/) before contributing. To help you with commit a commit template is provide.
Run `config.sh` to initialize the commit template to your `.git/config` or you can use

Once you are finished with your changes, run `npm test` to make sure all tests pass.

Do a pull request against `master`, make sure the build passes. A team member will review and merge your pull request.
Once merged to `master` one pull request will be created against `master`. Make sure that the CHANGELOG.md and the package.json is correct before merging the auto generated pull request. After the autogenerated
pull request has been merged to `master` the version will be bumped and published to npm.

==> generator-ibm-java-spring-2.1.0.tgz: package/README.md <==
# Yeoman generator for Spring code

[![IBM Cloud powered][img-cloud-powered]][url-bluemix]
[![Travis][img-travis]][url-travis]
[![Coveralls][img-coveralls-master]][url-coveralls-master]
[![Codacy][img-codacy]][url-codacy]
[![Version][img-version]][url-npm]
[![DownloadsMonthly][img-npm-downloads-monthly]][url-npm]
[![DownloadsTotal][img-npm-downloads-total]][url-npm]
[![License][img-license]][url-npm]
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)

[img-cloud-powered]: https://img.shields.io/badge/ibmcloud-powered-blue.svg
[url-bluemix]: http://bluemix.net

[img-travis]: https://travis-ci.org/ibm-developer/generator-ibm-java-spring.svg?branch=master
[url-travis]: https://travis-ci.org/ibm-developer/generator-ibm-java-spring

[img-coveralls-master]: https://coveralls.io/repos/github/ibm-developer/generator-ibm-java-spring/badge.svg
[url-coveralls-master]: https://coveralls.io/github/ibm-developer/generator-ibm-java-spring

[img-codacy]: https://api.codacy.com/project/badge/Grade/a5893a4622094dc8920c8a372a8d3588?branch=development
[url-codacy]: https://www.codacy.com/app/ibm-developer/generator-ibm-java-spring

[img-version]: https://img.shields.io/npm/v/generator-ibm-java-spring.svg
[url-npm]: https://www.npmjs.com/package/generator-ibm-java-spring

[img-npm-downloads-monthly]: https://img.shields.io/npm/dm/generator-ibm-java-spring.svg

[img-npm-downloads-total]: https://img.shields.io/npm/dt/generator-ibm-java-spring.svg

[img-license]: https://img.shields.io/npm/l/generator-ibm-java-spring.svg

This is a [yeoman generator](http://yeoman.io/) that will create Java code for you.

## Getting started:

To run the Yeoman generator simply type the following:

```bash
yo ibm-java (this generator is actually a sub-generator that the main java generator will compose with)
```

The generator provides the ability to generate Spring Java applications.

[Bluemix](https://console.ng.bluemix.net/) starters provide infrastructure files for building locally with Maven or Gradle and deploying to IBM Bluemix using containers. They also include code snippets to connect to any Bluemix services that are selected as part of the generation.

## Contribution

For contribution guidelines see the [GitHub repository](https://github.com/ibm-developer/generator-ibm-java-spring).
